@@ -2,18 +2,30 @@
 
 __author__ = """Qiusheng Wu"""
 __email__ = "giswqs@gmail.com"
-__version__ = "0.8.4"
+__version__ = "0.8.14"
+
+import os
 
 
 def in_colab_shell():
     """Tests if the code is being executed within Google Colab."""
-    try:
-        import google.colab  
+    import sys
+
+    if "google.colab" in sys.modules:
         return True
-    except ImportError:
+    else:
         return False
 
-if in_colab_shell():
+
+def use_folium():
+    """Whether to use the folium or ipyleaflet plotting backend."""
+    if os.environ.get("USE_FOLIUM") is not None:
+        return True
+    else:
+        return False
+
+
+if in_colab_shell() or use_folium():
     from .eefolium import *
 else:
-    from .geemap import *
\ No newline at end of file
+    from .geemap import *
