@@ -21,8 +21,8 @@ import subprocess
 try:
     import geemap
 except ImportError:
-    print('Installing geemap ...')
-    subprocess.check_call(["python", '-m', 'pip', 'install', 'geemap'])
+    print("Installing geemap ...")
+    subprocess.check_call(["python", "-m", "pip", "install", "geemap"])
 
 # %%
 import ee
@@ -35,7 +35,7 @@ The default basemap is `Google Maps`. [Additional basemaps](https://github.com/g
 """
 
 # %%
-Map = geemap.Map(center=[40,-100], zoom=4)
+Map = geemap.Map(center=[40, -100], zoom=4)
 Map
 
 # %%
@@ -45,22 +45,23 @@ Map
 
 # %%
 # Add Earth Engine dataset
-image = ee.Image('USGS/SRTMGL1_003')
+image = ee.Image("USGS/SRTMGL1_003")
 
 # Set visualization parameters.
 vis_params = {
-  'min': 0,
-  'max': 4000,
-  'palette': ['006633', 'E5FFCC', '662A00', 'D8D8D8', 'F5F5F5']}
+    "min": 0,
+    "max": 4000,
+    "palette": ["006633", "E5FFCC", "662A00", "D8D8D8", "F5F5F5"],
+}
 
 # Print the elevation of Mount Everest.
 xy = ee.Geometry.Point([86.9250, 27.9881])
-elev = image.sample(xy, 30).first().get('elevation').getInfo()
-print('Mount Everest elevation (m):', elev)
+elev = image.sample(xy, 30).first().get("elevation").getInfo()
+print("Mount Everest elevation (m):", elev)
 
 # Add Earth Engine layers to Map
-Map.addLayer(image, vis_params, 'DEM')
-Map.addLayer(xy, {'color': 'red'}, 'Mount Everest')
+Map.addLayer(image, vis_params, "DEM")
+Map.addLayer(xy, {"color": "red"}, "Mount Everest")
 
 # Center the map based on an Earth Engine object or coordinates (longitude, latitude)
 # Map.centerObject(xy, 4)
@@ -72,5 +73,5 @@ Map.setCenter(86.9250, 27.9881, 4)
 """
 
 # %%
-Map.addLayerControl() # This line is not needed for ipyleaflet-based Map.
-Map
\ No newline at end of file
+Map.addLayerControl()  # This line is not needed for ipyleaflet-based Map.
+Map
